@@ -35,7 +35,7 @@ class Config:
     The address of the Beaker server.
     """
 
-    default_org: Optional[str] = None
+    default_org: Optional[str] = "ai2"
     """
     Default Beaker organization to use.
     """
@@ -100,6 +100,9 @@ class Config:
             else:
                 raise ConfigurationError(f"Beaker config has no attribute '{name}'")
 
+        if not config.user_token:
+            raise ConfigurationError("Invalid Beaker user token, token is empty")
+
         return config
 
     @classmethod
