@@ -1,12 +1,19 @@
 from datetime import datetime
-from enum import Enum
-from typing import List, Optional
+from typing import List, Optional, Tuple
 
 from .account import Account
-from .base import BaseModel
+from .base import BaseModel, BasePage, StrEnum
 from .workspace import WorkspaceRef
 
-__all__ = ["Group", "GroupSpec", "GroupParameterType", "GroupParameter", "GroupPatch"]
+__all__ = [
+    "Group",
+    "GroupSpec",
+    "GroupParameterType",
+    "GroupParameter",
+    "GroupPatch",
+    "GroupsPage",
+    "GroupSort",
+]
 
 
 class Group(BaseModel):
@@ -18,6 +25,7 @@ class Group(BaseModel):
     created: datetime
     modified: datetime
     workspace_ref: Optional[WorkspaceRef] = None
+    description: Optional[str] = None
 
     @property
     def workspace(self) -> Optional[WorkspaceRef]:
@@ -31,7 +39,7 @@ class GroupSpec(BaseModel):
     experiments: Optional[List[str]] = None
 
 
-class GroupParameterType(str, Enum):
+class GroupParameterType(StrEnum):
     metric = "metric"
     env = "env"
 
@@ -47,3 +55,15 @@ class GroupPatch(BaseModel):
     add_experiments: Optional[List[str]] = None
     remove_experiments: Optional[List[str]] = None
     parameters: Optional[List[GroupParameter]] = None
+
+
+class GroupsPage(BasePage[Group]):
+    data: Tuple[Group, ...]
+
+
+class GroupSort(StrEnum):
+    created = "created"
+    modified = "modified"
+    author = "author"
+    group_name = "name"
+    group_name_or_description = "nameOrDescription"
